# Changelog

<!--next-version-placeholder-->

## v0.2.1 (2023-05-31)


## v0.2.0 (2023-05-08)
### Feature
* Import main tasks to __init__ so this plugin can be used as a library ([`61611cf`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/61611cf0f795221615e4e802bf8209280b1ef854))

## v0.1.9 (2023-05-04)
### Fix
* **compile:** Reverting change ([`6651cd7`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/6651cd77a07dfe9a7befee5bea39bfeff61ae061))

## v0.1.8 (2023-05-04)
### Fix
* **compile:** Allow multiple paths to be compiled at once. ([`2318a81`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/2318a81929ea2425845fb5569e018407a2a4cf52))

## v0.1.7 (2023-05-01)
### Fix
* **upgrade:** `pip.upgrade` now actually includes the upgrade flag to pip-compile ([`8ada23d`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/8ada23df192f3813a6628c0ca77169dadae058ca))

## v0.1.6 (2023-04-17)
### Fix
* **semver:** Semantic-release types should be a comma-separated string, not an array ([`4dd0394`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/4dd039434decb2ed8e2b1feff6a061f5bc49b4e3))

## v0.1.5 (2023-04-17)


## v0.1.4 (2023-04-17)
### Fix
* **project:** Remove theoretical support for Python versions below 3.10 since that has never worked ([`13f55b0`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/13f55b00cdc4f69c773c9771509e069dce2b8109))

## v0.1.3 (2023-04-11)
### Fix
* **pip.test:** Remove debug task ([`593dc8c`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/593dc8c4704dd17b519ae1bd8310938399d49b95))

## v0.1.2 (2023-04-11)
### Fix
* **deps:** Remove `pip.install-pip-tools` since that is a dependency of the plugin already ([`52a0658`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/52a0658d89e60bbc7a6ef972fc2638105090fa91))

### Documentation
* **readme:** Reference to changelog ([`0c28681`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/0c28681f36f56096cddf2cf0e7728a21b96fd42d))
* **changelog:** Manual fix changelog for missing version ([`0bce078`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/0bce078164b04ec93e26927294edf1a3daa76334))

## v0.1.1 (2023-04-11)
### Feature
* initial version of this plugin. ([`5624dd9`](https://github.com/educationwarehouse/edwh-pipcompile-plugin/commit/5624dd982dd0b1362616c2796209a1365fe966eb))
